ColumnInfo<T, V> class

Represents a processed column with state applied.

Constructors

ColumnInfo({required ColumnDef<T, V> def, required String id, required bool isVisible, required bool isPinnedLeft, required bool isPinnedRight, double? effectiveWidth, required int orderIndex})
const

Properties

def → ColumnDef<T, V>
final
effectiveWidth → double?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
isPinned → bool
no setter
isPinnedLeft → bool
final
isPinnedRight → bool
final
isVisible → bool
final
orderIndex → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited