GridState class

Constructors

GridState({List<SortEntry> sorting = const [], bool manualSorting = false, Map<String, dynamic> columnFilters = const {}, String? globalFilter, bool manualFiltering = false, PaginationState pagination = const PaginationState(), bool manualPagination = false, int? pageCount, int? totalItems, Map<String, bool> rowSelection = const {}, bool enableMultiRowSelection = true, bool selectAllPages = false, Map<String, bool> columnVisibility = const {}, List<String> columnOrder = const [], ColumnPinningState columnPinning = const ColumnPinningState(), Map<String, double> columnSizing = const {}, Map<String, bool> expanded = const {}, RowPinningState rowPinning = const RowPinningState(), List<String> grouping = const [], String? editingCellId})
const

Properties

columnFilters → Map<String, dynamic>
final
columnOrder → List<String>
final
columnPinning → ColumnPinningState
final
columnSizing → Map<String, double>
final
columnVisibility → Map<String, bool>
final
editingCellId → String?
final
enableMultiRowSelection → bool
final
expanded → Map<String, bool>
final
globalFilter → String?
final
grouping → List<String>
final
hasActiveFilters → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasSelection → bool
no setter
manualFiltering → bool
final
manualPagination → bool
final
manualSorting → bool
final
pageCount → int?
final
pagination → PaginationState
final
rowPinning → RowPinningState
final
rowSelection → Map<String, bool>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectAllPages → bool
final
selectedCount → int
no setter
sorting → List<SortEntry>
final
sortString → String?
no setter
totalItems → int?
final

Methods

copyWith({List<SortEntry>? sorting, bool? manualSorting, Map<String, dynamic>? columnFilters, String? globalFilter, bool clearGlobalFilter = false, bool? manualFiltering, PaginationState? pagination, bool? manualPagination, int? pageCount, int? totalItems, Map<String, bool>? rowSelection, bool? enableMultiRowSelection, bool? selectAllPages, Map<String, bool>? columnVisibility, List<String>? columnOrder, ColumnPinningState? columnPinning, Map<String, double>? columnSizing, Map<String, bool>? expanded, RowPinningState? rowPinning, List<String>? grouping, String? editingCellId, bool clearEditingCell = false}) → GridState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toQuery() → GridQuery
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited