RowDndFeature class

Inheritance

Constructors

RowDndFeature({void onRowReorder(int fromIndex, int toIndex)?})

Properties

featureId → String
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
manual → bool
no setterinherited
onRowReorder → void Function(int fromIndex, int toIndex)?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
inherited
init(dynamic controller) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited